/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright (c) 2012 Oracle and/or its affiliates. All rights reserved.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common Development
 * and Distribution License("CDDL") (collectively, the "License").  You
 * may not use this file except in compliance with the License.  You can
 * obtain a copy of the License at
 * https://glassfish.dev.java.net/public/CDDL+GPL_1_1.html
 * or packager/legal/LICENSE.txt.  See the License for the specific
 * language governing permissions and limitations under the License.
 *
 * When distributing the software, include this License Header Notice in each
 * file and include the License file at packager/legal/LICENSE.txt.
 *
 * GPL Classpath Exception:
 * Oracle designates this particular file as subject to the "Classpath"
 * exception as provided by Oracle in the GPL Version 2 section of the License
 * file that accompanied this code.
 *
 * Modifications:
 * If applicable, add the following below the License Header, with the fields
 * enclosed by brackets [] replaced by your own identifying information:
 * "Portions Copyright [year] [name of copyright owner]"
 *
 * Contributor(s):
 * If you wish your version of this file to be governed by only the CDDL or
 * only the GPL Version 2, indicate your decision by adding "[Contributor]
 * elects to include this software in this distribution under the [CDDL or GPL
 * Version 2] license."  If you don't indicate a single choice of license, a
 * recipient has the option to distribute your version of this file under
 * either the CDDL, the GPL Version 2 or to extend the choice of license to
 * its licensees as provided above.  However, if you add GPL Version 2 code
 * and therefore, elected the GPL Version 2 license, then the option applies
 * only if the new code is made subject to such option by the copyright
 * holder.
 */
package org.glassfish.osgicdi.impl;

import org.jboss.weld.resources.spi.ResourceLoader;
import org.jboss.weld.resources.spi.ResourceLoadingException;
import org.osgi.framework.Bundle;

import java.io.IOException;
import java.net.URL;
import java.util.ArrayList;
import java.util.Collection;
import java.util.Enumeration;
import java.util.List;

/**
 * A simple resource loader.
 * <p/>
 * Uses {@link OSGiBeanResourceLoader}'s classloader if the Thread Context
 * Classloader isn't available
 *
 * @author Tang Yong(tangyong@cn.fujitsu.com)
 */
public class OSGiBeanResourceLoader implements ResourceLoader {
    private final Bundle bundle;

    public OSGiBeanResourceLoader(Bundle bundle) {
        this.bundle = bundle;
    }

    @Override
    public Class<?> classForName(String name) {
        try {
            Class<?> clazz = bundle.loadClass(name);            
            return clazz;
        } catch (ClassNotFoundException e) {
            throw new ResourceLoadingException(e);
        } catch (NoClassDefFoundError e) {
            throw new ResourceLoadingException(e);
        }
    }

    @Override
    public URL getResource(String name) {
        return bundle.getResource(name);
    }

    @SuppressWarnings("unchecked")
	@Override
    public Collection<URL> getResources(String name) {
        try {
        	List<URL> list = new ArrayList<URL>();
        	Enumeration<URL> enumeration = bundle.getResources(name);
        	while (enumeration.hasMoreElements()) {
                list.add(enumeration.nextElement());
            }
        	
        	return list;
        } catch (IOException e) {
            throw new ResourceLoadingException(e);
        }
    }

    @Override
    public void cleanup() {
    }
}
